import { ORIGIN_URL, REQUEST } from '@nguniversal/aspnetcore-engine/tokens';
import { CommonEngine } from '@nguniversal/common/engine';
import { createDocument } from 'domino';

/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */
/* @internal */
function _getUniversalData(content, appSelector) {
    const doc = createDocument(content, true);
    const styles = [];
    const scripts = [];
    const meta = [];
    const links = [];
    // eslint-disable-next-line @typescript-eslint/no-non-null-assertion
    const elements = [...Array.from(doc.head.children), ...Array.from(doc.body.children)];
    for (const element of elements) {
        switch (element.tagName.toUpperCase()) {
            case 'SCRIPT':
                scripts.push(element.outerHTML);
                break;
            case 'STYLE':
                styles.push(element.outerHTML);
                break;
            case 'LINK':
                links.push(element.outerHTML);
                break;
            case 'META':
                meta.push(element.outerHTML);
                break;
            default:
                break;
        }
    }
    return {
        completeHTML: content,
        // eslint-disable-next-line @typescript-eslint/no-non-null-assertion
        html: doc.querySelector(appSelector).outerHTML,
        globals: {
            title: doc.title,
            scripts: scripts.join('\n'),
            styles: styles.join('\n'),
            meta: meta.join('\n'),
            links: links.join('\n'),
        },
    };
}
const commonEngine = new CommonEngine();
/** @deprecated use `@nguniversal/common` instead. */
async function ngAspnetCoreEngine(options) {
    if (!options.appSelector) {
        const selector = `" appSelector: '<app-root></app-root>' "`;
        throw new Error(`appSelector is required! Pass in ${selector},
     for your root App component.`);
    }
    const renderOptions = {
        url: options.url || options.request.absoluteUrl,
        document: options.document || options.appSelector,
        providers: [
            ...(options.providers || []),
            getReqResProviders(options.request.origin, options.request.data.request),
        ],
        bootstrap: options.ngModule,
        inlineCriticalCss: options.inlineCriticalCss,
        publicPath: options.publicPath,
    };
    // Grab the DOM "selector" from the passed in Template <app-root> for example = "app-root"
    const appSelector = options.appSelector.substring(1, options.appSelector.indexOf('>'));
    const html = await commonEngine.render(renderOptions);
    return _getUniversalData(html, appSelector);
}
/**
 * Get providers of the request and response
 */
function getReqResProviders(origin, request) {
    const providers = [
        {
            provide: ORIGIN_URL,
            useValue: origin,
        },
        {
            provide: REQUEST,
            useValue: request,
        },
    ];
    return providers;
}

/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */
/** @deprecated use `@nguniversal/common` instead. */
function createTransferScript(transferData) {
    return `<script>window['TRANSFER_CACHE'] = ${JSON.stringify(transferData)};</script>`;
}

/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * Generated bundle index. Do not edit.
 */

export { createTransferScript, ngAspnetCoreEngine };
//# sourceMappingURL=aspnetcore-engine.mjs.map
